GO class

Constructors

GO()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

GoAlert → const FIconObject
GoAlertFill → const FIconObject
GoArchive → const FIconObject
GoArrowBoth → const FIconObject
GoArrowDown → const FIconObject
GoArrowDownLeft → const FIconObject
GoArrowDownRight → const FIconObject
GoArrowLeft → const FIconObject
GoArrowRight → const FIconObject
GoArrowSwitch → const FIconObject
GoArrowUp → const FIconObject
GoArrowUpLeft → const FIconObject
GoArrowUpRight → const FIconObject
GoBeaker → const FIconObject
GoBell → const FIconObject
GoBellFill → const FIconObject
GoBellSlash → const FIconObject
GoBlocked → const FIconObject
GoBold → const FIconObject
GoBook → const FIconObject
GoBookmark → const FIconObject
GoBookmarkFill → const FIconObject
GoBookmarkSlash → const FIconObject
GoBookmarkSlashFill → const FIconObject
GoBriefcase → const FIconObject
GoBroadcast → const FIconObject
GoBrowser → const FIconObject
GoBug → const FIconObject
GoCalendar → const FIconObject
GoCheck → const FIconObject
GoCheckbox → const FIconObject
GoCheckCircle → const FIconObject
GoCheckCircleFill → const FIconObject
GoChecklist → const FIconObject
GoChevronDown → const FIconObject
GoChevronLeft → const FIconObject
GoChevronRight → const FIconObject
GoChevronUp → const FIconObject
GoCircle → const FIconObject
GoCircleSlash → const FIconObject
GoClock → const FIconObject
GoClockFill → const FIconObject
GoCloud → const FIconObject
GoCloudOffline → const FIconObject
GoCode → const FIconObject
GoCodeOfConduct → const FIconObject
GoCodeReview → const FIconObject
GoCodescan → const FIconObject
GoCodescanCheckmark → const FIconObject
GoCodespaces → const FIconObject
GoCodeSquare → const FIconObject
GoColumns → const FIconObject
GoCommandPalette → const FIconObject
GoComment → const FIconObject
GoCommentDiscussion → const FIconObject
GoCommit → const FIconObject
GoContainer → const FIconObject
GoCopilot → const FIconObject
GoCopy → const FIconObject
GoCpu → const FIconObject
GoCreditCard → const FIconObject
GoCrossReference → const FIconObject
GoDash → const FIconObject
GoDatabase → const FIconObject
GoDependabot → const FIconObject
GoDesktopDownload → const FIconObject
GoDeviceCameraVideo → const FIconObject
GoDeviceDesktop → const FIconObject
GoDeviceMobile → const FIconObject
GoDiamond → const FIconObject
GoDiff → const FIconObject
GoDiscussionClosed → const FIconObject
GoDiscussionDuplicate → const FIconObject
GoDiscussionOutdated → const FIconObject
GoDot → const FIconObject
GoDotFill → const FIconObject
GoDownload → const FIconObject
GoDuplicate → const FIconObject
GoEye → const FIconObject
GoEyeClosed → const FIconObject
GoFile → const FIconObject
GoFileBinary → const FIconObject
GoFileCode → const FIconObject
GoFileDiff → const FIconObject
GoFileDirectory → const FIconObject
GoFileDirectoryFill → const FIconObject
GoFileMedia → const FIconObject
GoFileSubmodule → const FIconObject
GoFileSymlinkFile → const FIconObject
GoFileZip → const FIconObject
GoFilter → const FIconObject
GoFlame → const FIconObject
GoFold → const FIconObject
GoFoldDown → const FIconObject
GoFoldUp → const FIconObject
GoGear → const FIconObject
GoGift → const FIconObject
GoGitBranch → const FIconObject
GoGitCommit → const FIconObject
GoGitCompare → const FIconObject
GoGitMerge → const FIconObject
GoGitMergeQueue → const FIconObject
GoGitPullRequest → const FIconObject
GoGitPullRequestClosed → const FIconObject
GoGitPullRequestDraft → const FIconObject
GoGlobe → const FIconObject
GoGoal → const FIconObject
GoGrabber → const FIconObject
GoGraph → const FIconObject
GoHash → const FIconObject
GoHeading → const FIconObject
GoHeart → const FIconObject
GoHeartFill → const FIconObject
GoHistory → const FIconObject
GoHome → const FIconObject
GoHomeFill → const FIconObject
GoHorizontalRule → const FIconObject
GoHourglass → const FIconObject
GoHubot → const FIconObject
GoImage → const FIconObject
GoInbox → const FIconObject
GoInfinity → const FIconObject
GoInfo → const FIconObject
GoIssueClosed → const FIconObject
GoIssueDraft → const FIconObject
GoIssueOpened → const FIconObject
GoIssueReopened → const FIconObject
GoIssueTrackedBy → const FIconObject
GoIssueTracks → const FIconObject
GoItalic → const FIconObject
GoIterations → const FIconObject
GoKebabHorizontal → const FIconObject
GoKey → const FIconObject
GoLaw → const FIconObject
GoLightBulb → const FIconObject
GoLinkExternal → const FIconObject
GoListOrdered → const FIconObject
GoListUnordered → const FIconObject
GoLocation → const FIconObject
GoLock → const FIconObject
GoLog → const FIconObject
GoMail → const FIconObject
GoMegaphone → const FIconObject
GoMention → const FIconObject
GoMilestone → const FIconObject
GoMirror → const FIconObject
GoMoon → const FIconObject
GoMortarBoard → const FIconObject
GoMoveToBottom → const FIconObject
GoMoveToEnd → const FIconObject
GoMoveToStart → const FIconObject
GoMoveToTop → const FIconObject
GoMultiSelect → const FIconObject
GoMute → const FIconObject
GoNoEntry → const FIconObject
GoNorthStar → const FIconObject
GoNote → const FIconObject
GoNumber → const FIconObject
GoOrganization → const FIconObject
GoPackage → const FIconObject
GoPackageDependencies → const FIconObject
GoPackageDependents → const FIconObject
GoPaperAirplane → const FIconObject
GoPaperclip → const FIconObject
GoPasskeyFill → const FIconObject
GoPaste → const FIconObject
GoPencil → const FIconObject
GoPeople → const FIconObject
GoPerson → const FIconObject
GoPersonAdd → const FIconObject
GoPersonFill → const FIconObject
GoPin → const FIconObject
GoPlay → const FIconObject
GoPlug → const FIconObject
GoPlus → const FIconObject
GoPlusCircle → const FIconObject
GoProject → const FIconObject
GoProjectRoadmap → const FIconObject
GoProjectTemplate → const FIconObject
GoPulse → const FIconObject
GoQuestion → const FIconObject
GoQuote → const FIconObject
GoRead → const FIconObject
GoRelFilePath → const FIconObject
GoReply → const FIconObject
GoRepo → const FIconObject
GoRepoForked → const FIconObject
GoRepoLocked → const FIconObject
GoRepoPush → const FIconObject
GoReport → const FIconObject
GoRepoTemplate → const FIconObject
GoRocket → const FIconObject
GoRows → const FIconObject
GoRss → const FIconObject
GoRuby → const FIconObject
GoScreenFull → const FIconObject
GoScreenNormal → const FIconObject
GoSearch → const FIconObject
GoServer → const FIconObject
GoShare → const FIconObject
GoShareAndroid → const FIconObject
GoShield → const FIconObject
GoShieldCheck → const FIconObject
GoShieldLock → const FIconObject
GoShieldSlash → const FIconObject
GoShieldX → const FIconObject
GoSidebarCollapse → const FIconObject
GoSidebarExpand → const FIconObject
GoSignIn → const FIconObject
GoSignOut → const FIconObject
GoSingleSelect → const FIconObject
GoSkip → const FIconObject
GoSkipFill → const FIconObject
GoSmiley → const FIconObject
GoSortAsc → const FIconObject
GoSortDesc → const FIconObject
GoSponsorTiers → const FIconObject
GoSquare → const FIconObject
GoSquareFill → const FIconObject
GoSquirrel → const FIconObject
GoStack → const FIconObject
GoStar → const FIconObject
GoStarFill → const FIconObject
GoStop → const FIconObject
GoStopwatch → const FIconObject
GoStrikethrough → const FIconObject
GoSun → const FIconObject
GoSync → const FIconObject
GoTab → const FIconObject
GoTable → const FIconObject
GoTag → const FIconObject
GoTasklist → const FIconObject
GoTelescope → const FIconObject
GoTelescopeFill → const FIconObject
GoTerminal → const FIconObject
GoThumbsdown → const FIconObject
GoThumbsup → const FIconObject
GoTools → const FIconObject
GoTrash → const FIconObject
GoTriangleDown → const FIconObject
GoTriangleLeft → const FIconObject
GoTriangleRight → const FIconObject
GoTriangleUp → const FIconObject
GoTrophy → const FIconObject
GoTypography → const FIconObject
GoUnfold → const FIconObject
GoUnlock → const FIconObject
GoUnmute → const FIconObject
GoUnread → const FIconObject
GoUnverified → const FIconObject
GoUpload → const FIconObject
GoVerified → const FIconObject
GoVersions → const FIconObject
GoVideo → const FIconObject
GoWorkflow → const FIconObject
GoX → const FIconObject
GoXCircle → const FIconObject
GoXCircleFill → const FIconObject
GoZap → const FIconObject
GoZoomIn → const FIconObject
GoZoomOut → const FIconObject